@@ -10,7 +10,7 @@ const Confirmation = () => (
         </p>
         <br />
         <a
-            href="https://nxbus.co.uk/dundee/"
+            href="https://www.nxdiscovrit.co.uk/"
             title="National Express Xplore Dundee"
             className="primary">
             Back to Xplore Site
