@@ -29,7 +29,7 @@ class AdminController
         $data = '<p>Please enter the Journey Date:</p>';
 
         $data .= '
-            <form action="" method="POST" name="journeySelectForm">
+            <form action="" method="GET" id="journeySelectForm" name="journeySelectForm">
                 <input type="date" name="journeyDate" placeholder="Please select the date" required>    
                 <select name="time" required>
                     <option value="0230">02:30</option>
@@ -59,16 +59,17 @@ class AdminController
         ';
 
         echo $data;
+        exit;
     }
 
     public function printDriverManifest()
     {
 
-        if (isset($_POST['journeyDate'])) {
+        if (isset($_GET['journeyDate'])) {
 
-            $date = $_POST['journeyDate'];
-            $time = $_POST['time'];
-            $direction = $_POST['direction'];
+            $date = $_GET['journeyDate'];
+            $time = $_GET['time'];
+            $direction = $_GET['direction'];
 
             $date = date('d-m-Y', strtotime($date));
 
